@@ -24,10 +24,10 @@ import org.jcodings.ISOEncoding;
 import org.jcodings.IntHolder;
 import org.jcodings.constants.CharacterType;
 
-public final class ISO8859_15Encoding extends ISOEncoding {
+public final class ISO8859_13Encoding extends ISOEncoding {
 
-    protected ISO8859_15Encoding() {
-        super("ISO-8859-15", ISO8859_15CtypeTable, ISO8859_15ToLowerCaseTable, ISO8859_15CaseFoldMap);
+    protected ISO8859_13Encoding() {
+        super("ISO-8859-13", ISO8859_13CtypeTable, ISO8859_13ToLowerCaseTable, ISO8859_13CaseFoldMap);
     }
 
     @Override
@@ -47,22 +47,17 @@ public final class ISO8859_15Encoding extends ISOEncoding {
                     to[toP++] = 's';
                     code = 's';
                 }
-            } else if (code == 0xAA || code == 0xBA || code == 0xB5) {
-            } else if ((ISO8859_15CtypeTable[code] & CharacterType.BIT_UPPER) != 0 && (flags & (Config.CASE_DOWNCASE | Config.CASE_FOLD)) != 0) {
+            } else if ((ISO8859_13CtypeTable[code] & CharacterType.BIT_UPPER) != 0 && (flags & (Config.CASE_DOWNCASE | Config.CASE_FOLD)) != 0) {
                 flags |= Config.CASE_MODIFIED;
                 code = LowerCaseTable[code];
-            } else if ((ISO8859_15CtypeTable[code] & CharacterType.BIT_LOWER) != 0 && (flags & Config.CASE_UPCASE) != 0) {
+            } else if (code == 0xB5) {
+            } else if ((ISO8859_13CtypeTable[code] & CharacterType.BIT_LOWER) != 0 && (flags & Config.CASE_UPCASE) != 0) {
                 flags |= Config.CASE_MODIFIED;
-                if (code == 0xA8)
-                    code -= 2;
-                else if (code == 0xB8)
-                    code -= 4;
-                else if (code == 0xBD)
-                    code -= 1;
-                else if (code == 0xFF)
-                    code -= 0x41;
-                else
+                if (code == 0xB8 || code == 0xBA || code == 0xBF) {
+                    code -= 0x10;
+                } else {
                     code -= 0x20;
+                }
             }
             to[toP++] = (byte)code;
             if ((flags & Config.CASE_TITLECASE) != 0) {
@@ -73,7 +68,8 @@ public final class ISO8859_15Encoding extends ISOEncoding {
         return toP - toStart;
     }
 
-    static final short ISO8859_15CtypeTable[] = {
+
+    static final short ISO8859_13CtypeTable[] = {
         0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008,
         0x4008, 0x420c, 0x4209, 0x4208, 0x4208, 0x4208, 0x4008, 0x4008,
         0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008,
@@ -94,10 +90,10 @@ public final class ISO8859_15Encoding extends ISOEncoding {
         0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
         0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
         0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
-        0x0284, 0x01a0, 0x00a0, 0x00a0, 0x00a0, 0x00a0, 0x34a2, 0x00a0,
-        0x30e2, 0x00a0, 0x30e2, 0x01a0, 0x00a0, 0x01a0, 0x00a0, 0x00a0,
-        0x00a0, 0x00a0, 0x10a0, 0x10a0, 0x34a2, 0x30e2, 0x00a0, 0x01a0,
-        0x30e2, 0x10a0, 0x30e2, 0x01a0, 0x34a2, 0x30e2, 0x34a2, 0x01a0,
+        0x0284, 0x01a0, 0x00a0, 0x00a0, 0x00a0, 0x01a0, 0x00a0, 0x00a0,
+        0x34a2, 0x00a0, 0x34a2, 0x01a0, 0x00a0, 0x01a0, 0x00a0, 0x34a2,
+        0x00a0, 0x00a0, 0x10a0, 0x10a0, 0x01a0, 0x30e2, 0x00a0, 0x01a0,
+        0x30e2, 0x10a0, 0x30e2, 0x01a0, 0x10a0, 0x10a0, 0x10a0, 0x30e2,
         0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
         0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
         0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x00a0,
@@ -105,10 +101,10 @@ public final class ISO8859_15Encoding extends ISOEncoding {
         0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
         0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
         0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x00a0,
-        0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2
+        0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x01a0
     };
 
-    static final byte ISO8859_15ToLowerCaseTable[] = new byte[]{
+    static final byte ISO8859_13ToLowerCaseTable[] = new byte[]{
         (byte)'\000', (byte)'\001', (byte)'\002', (byte)'\003', (byte)'\004', (byte)'\005', (byte)'\006', (byte)'\007',
         (byte)'\010', (byte)'\011', (byte)'\012', (byte)'\013', (byte)'\014', (byte)'\015', (byte)'\016', (byte)'\017',
         (byte)'\020', (byte)'\021', (byte)'\022', (byte)'\023', (byte)'\024', (byte)'\025', (byte)'\026', (byte)'\027',
@@ -129,10 +125,10 @@ public final class ISO8859_15Encoding extends ISOEncoding {
         (byte)'\210', (byte)'\211', (byte)'\212', (byte)'\213', (byte)'\214', (byte)'\215', (byte)'\216', (byte)'\217',
         (byte)'\220', (byte)'\221', (byte)'\222', (byte)'\223', (byte)'\224', (byte)'\225', (byte)'\226', (byte)'\227',
         (byte)'\230', (byte)'\231', (byte)'\232', (byte)'\233', (byte)'\234', (byte)'\235', (byte)'\236', (byte)'\237',
-        (byte)'\240', (byte)'\241', (byte)'\242', (byte)'\243', (byte)'\244', (byte)'\245', (byte)'\250', (byte)'\247',
-        (byte)'\250', (byte)'\251', (byte)'\252', (byte)'\253', (byte)'\254', (byte)'\255', (byte)'\256', (byte)'\257',
-        (byte)'\260', (byte)'\261', (byte)'\262', (byte)'\263', (byte)'\270', (byte)'\265', (byte)'\266', (byte)'\267',
-        (byte)'\270', (byte)'\271', (byte)'\272', (byte)'\273', (byte)'\275', (byte)'\275', (byte)'\377', (byte)'\277',
+        (byte)'\240', (byte)'\241', (byte)'\242', (byte)'\243', (byte)'\244', (byte)'\245', (byte)'\246', (byte)'\247',
+        (byte)'\270', (byte)'\251', (byte)'\272', (byte)'\253', (byte)'\254', (byte)'\255', (byte)'\256', (byte)'\277',
+        (byte)'\260', (byte)'\261', (byte)'\262', (byte)'\263', (byte)'\264', (byte)'\265', (byte)'\266', (byte)'\267',
+        (byte)'\270', (byte)'\271', (byte)'\272', (byte)'\273', (byte)'\274', (byte)'\275', (byte)'\276', (byte)'\277',
         (byte)'\340', (byte)'\341', (byte)'\342', (byte)'\343', (byte)'\344', (byte)'\345', (byte)'\346', (byte)'\347',
         (byte)'\350', (byte)'\351', (byte)'\352', (byte)'\353', (byte)'\354', (byte)'\355', (byte)'\356', (byte)'\357',
         (byte)'\360', (byte)'\361', (byte)'\362', (byte)'\363', (byte)'\364', (byte)'\365', (byte)'\366', (byte)'\327',
@@ -143,13 +139,7 @@ public final class ISO8859_15Encoding extends ISOEncoding {
         (byte)'\370', (byte)'\371', (byte)'\372', (byte)'\373', (byte)'\374', (byte)'\375', (byte)'\376', (byte)'\377'
     };
 
-    static final int ISO8859_15CaseFoldMap[][] = {
-        { 0xa6, 0xa8 },
-
-        { 0xb4, 0xb8 },
-        { 0xbc, 0xbd },
-        { 0xbe, 0xff },
-
+    static final int ISO8859_13CaseFoldMap[][] = {
         { 0xc0, 0xe0 },
         { 0xc1, 0xe1 },
         { 0xc2, 0xe2 },
@@ -183,5 +173,5 @@ public final class ISO8859_15Encoding extends ISOEncoding {
         { 0xde, 0xfe }
     };
 
-    public static final ISO8859_15Encoding INSTANCE = new ISO8859_15Encoding();
+    public static final ISO8859_13Encoding INSTANCE = new ISO8859_13Encoding();
 }
