@@ -20,6 +20,7 @@
 package org.jcodings.transcode;
 
 import org.jcodings.transcode.Transcoder.GenericTranscoderEntry;
+import org.jcodings.transcode.specific.*;
 
 final class TranscoderList {
     static void load() {
@@ -251,8 +252,6 @@ final class TranscoderList {
         new GenericTranscoderEntry("UTF-8", "UTF8-SoftBank", 24060, "Emoji", 1, 4, 6, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("stateless-ISO-2022-JP-KDDI", "UTF8-KDDI", 33996, "EmojiIso2022Kddi", 1, 3, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("UTF8-KDDI", "stateless-ISO-2022-JP-KDDI", 76404, "EmojiIso2022Kddi", 1, 4, 3, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("ISO-2022-JP-KDDI", "stateless-ISO-2022-JP-KDDI", 56, "EmojiIso2022Kddi", 1, 3, 3, AsciiCompatibility.DECODER, 1),
-        new GenericTranscoderEntry("stateless-ISO-2022-JP-KDDI", "ISO-2022-JP-KDDI", 108, "EmojiIso2022Kddi", 1, 3, 5, AsciiCompatibility.ENCODER, 1),
         new GenericTranscoderEntry("SJIS-DOCOMO", "UTF8-DOCOMO", 39616, "EmojiSjisDocomo", 1, 2, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("UTF8-DOCOMO", "SJIS-DOCOMO", 84704, "EmojiSjisDocomo", 1, 4, 2, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("SJIS-KDDI", "UTF8-KDDI", 39616, "EmojiSjisKddi", 1, 2, 1, AsciiCompatibility.CONVERTER, 0),
@@ -262,21 +261,8 @@ final class TranscoderList {
         new GenericTranscoderEntry("", "amp_escape", 8, "Escape", 1, 1, 5, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("", "xml_text_escape", 32, "Escape", 1, 1, 5, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("", "xml_attr_content_escape", 60, "Escape", 1, 1, 6, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("", "xml_attr_quote", 72, "Escape", 1, 1, 7, AsciiCompatibility.ENCODER, 1),
-        new GenericTranscoderEntry("GB18030", "UTF-8", 57668, "Gb18030", 1, 4, 4, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "GB18030", 115576, "Gb18030", 1, 4, 4, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("GBK", "UTF-8", 89284, "Gbk", 1, 2, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("UTF-8", "GBK", 182912, "Gbk", 1, 4, 2, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("ISO-2022-JP", "stateless-ISO-2022-JP", 56, "Iso2022", 1, 3, 3, AsciiCompatibility.DECODER, 1),
-        new GenericTranscoderEntry("stateless-ISO-2022-JP", "ISO-2022-JP", 108, "Iso2022", 1, 3, 5, AsciiCompatibility.ENCODER, 1),
-        new GenericTranscoderEntry("stateless-ISO-2022-JP", "EUC-JP", 128, "Iso2022", 1, 3, 2, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("EUC-JP", "stateless-ISO-2022-JP", 192, "Iso2022", 1, 3, 3, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("CP50220", "cp51932", 244, "Iso2022", 1, 3, 3, AsciiCompatibility.DECODER, 1),
-        new GenericTranscoderEntry("CP50221", "cp51932", 244, "Iso2022", 1, 3, 3, AsciiCompatibility.DECODER, 1),
-        new GenericTranscoderEntry("CP51932", "CP50221", 268, "Iso2022", 1, 3, 5, AsciiCompatibility.ENCODER, 1),
-        new GenericTranscoderEntry("CP51932", "CP50220", 268, "Iso2022", 1, 3, 5, AsciiCompatibility.ENCODER, 3),
-        new GenericTranscoderEntry("EUC-JP", "Shift_JIS", 88, "Japanese", 1, 3, 2, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("Shift_JIS", "EUC-JP", 132, "Japanese", 1, 2, 2, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("EUC-JP", "UTF-8", 54488, "JapaneseEuc", 1, 3, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("eucJP-ms", "UTF-8", 64480, "JapaneseEuc", 1, 3, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("CP51932", "UTF-8", 66380, "JapaneseEuc", 1, 2, 1, AsciiCompatibility.CONVERTER, 0),
@@ -293,7 +279,6 @@ final class TranscoderList {
         new GenericTranscoderEntry("EUC-KR", "UTF-8", 78500, "Korean", 1, 2, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("UTF-8", "CP949", 126176, "Korean", 1, 4, 2, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("CP949", "UTF-8", 196644, "Korean", 1, 2, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("", "universal_newline", 4, "Newline", 1, 1, 2, AsciiCompatibility.CONVERTER, 2),
         new GenericTranscoderEntry("", "crlf_newline", 20, "Newline", 1, 1, 2, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("", "cr_newline", 36, "Newline", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("US-ASCII", "UTF-8", 8, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
@@ -342,79 +327,101 @@ final class TranscoderList {
         new GenericTranscoderEntry("UTF-8", "WINDOWS-1253", 21152, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("WINDOWS-1254", "UTF-8", 21652, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
         new GenericTranscoderEntry("UTF-8", "WINDOWS-1254", 21768, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("WINDOWS-1255", "UTF-8", 22204, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "WINDOWS-1255", 22976, "SingleByte", 1, 4, 3, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("WINDOWS-1256", "UTF-8", 23500, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "WINDOWS-1256", 24244, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("WINDOWS-1257", "UTF-8", 24724, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "WINDOWS-1257", 24944, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM437", "UTF-8", 25468, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM437", 26304, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM775", "UTF-8", 26828, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM775", 27472, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM737", "UTF-8", 27996, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM737", 28508, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM852", "UTF-8", 29032, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM852", 29648, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM855", "UTF-8", 30172, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM855", 30724, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM857", "UTF-8", 31240, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM857", 31752, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM860", "UTF-8", 32276, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM860", 32664, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM861", "UTF-8", 33188, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM861", 33500, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM862", "UTF-8", 34024, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM862", 34268, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM863", "UTF-8", 34792, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM863", 35172, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM865", "UTF-8", 35696, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM865", 36008, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM866", "UTF-8", 36532, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM866", 36988, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("IBM869", "UTF-8", 37480, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "IBM869", 37996, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACCROATIAN", "UTF-8", 38520, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACCROATIAN", 39352, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACCYRILLIC", "UTF-8", 39876, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACCYRILLIC", 40580, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACGREEK", "UTF-8", 41104, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACGREEK", 41804, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACICELAND", "UTF-8", 42328, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACICELAND", 43044, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACROMAN", "UTF-8", 43568, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACROMAN", 44052, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACROMANIA", "UTF-8", 44576, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACROMANIA", 44952, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACTURKISH", "UTF-8", 45472, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACTURKISH", 45828, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("MACUKRAINE", "UTF-8", 46352, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "MACUKRAINE", 46576, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("KOI8-U", "UTF-8", 47100, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "KOI8-U", 47884, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("KOI8-R", "UTF-8", 48408, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "KOI8-R", 48940, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("TIS-620", "UTF-8", 49304, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "TIS-620", 49348, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("CP850", "UTF-8", 49872, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "CP850", 50420, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("CP852", "UTF-8", 29032, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "CP852", 29648, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("CP855", "UTF-8", 30172, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "CP855", 30724, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF-8", "UTF8-MAC", 52420, "Utf8Mac", 1, 4, 9, AsciiCompatibility.CONVERTER, 0),
-        new GenericTranscoderEntry("UTF8-MAC", "UTF-8", 52544, "Utf8Mac", 1, 4, 10, AsciiCompatibility.ENCODER, 0),
-        new GenericTranscoderEntry("UTF-16BE", "UTF-8", 188, "Utf1632", 2, 4, 4, AsciiCompatibility.DECODER, 0),
-        new GenericTranscoderEntry("UTF-8", "UTF-16BE", 416, "Utf1632", 1, 4, 4, AsciiCompatibility.ENCODER, 0),
-        new GenericTranscoderEntry("UTF-16LE", "UTF-8", 52, "Utf1632", 2, 4, 4, AsciiCompatibility.DECODER, 0),
-        new GenericTranscoderEntry("UTF-8", "UTF-16LE", 416, "Utf1632", 1, 4, 4, AsciiCompatibility.ENCODER, 0),
-        new GenericTranscoderEntry("UTF-32BE", "UTF-8", 252, "Utf1632", 4, 4, 4, AsciiCompatibility.DECODER, 0),
-        new GenericTranscoderEntry("UTF-8", "UTF-32BE", 416, "Utf1632", 1, 4, 4, AsciiCompatibility.ENCODER, 0),
-        new GenericTranscoderEntry("UTF-32LE", "UTF-8", 128, "Utf1632", 4, 4, 4, AsciiCompatibility.DECODER, 0),
-        new GenericTranscoderEntry("UTF-8", "UTF-32LE", 416, "Utf1632", 1, 4, 4, AsciiCompatibility.ENCODER, 0),
-        new GenericTranscoderEntry("UTF-16", "UTF-8", 276, "Utf1632", 2, 4, 4, AsciiCompatibility.DECODER, 1),
-        new GenericTranscoderEntry("UTF-32", "UTF-8", 300, "Utf1632", 4, 4, 4, AsciiCompatibility.DECODER, 1),
-        new GenericTranscoderEntry("UTF-8", "UTF-16", 416, "Utf1632", 1, 4, 4, AsciiCompatibility.ENCODER, 1),
-        new GenericTranscoderEntry("UTF-8", "UTF-32", 416, "Utf1632", 1, 4, 4, AsciiCompatibility.ENCODER, 1)
+        new GenericTranscoderEntry("WINDOWS-1255", "UTF-8", 22208, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "WINDOWS-1255", 22984, "SingleByte", 1, 4, 3, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("WINDOWS-1256", "UTF-8", 23508, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "WINDOWS-1256", 24252, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("WINDOWS-1257", "UTF-8", 24732, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "WINDOWS-1257", 24952, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM437", "UTF-8", 25476, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM437", 26312, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM775", "UTF-8", 26836, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM775", 27480, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM737", "UTF-8", 28004, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM737", 28516, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM852", "UTF-8", 29040, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM852", 29656, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM855", "UTF-8", 30180, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM855", 30732, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM857", "UTF-8", 31248, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM857", 31760, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM860", "UTF-8", 32284, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM860", 32672, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM861", "UTF-8", 33196, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM861", 33508, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM862", "UTF-8", 34032, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM862", 34276, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM863", "UTF-8", 34800, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM863", 35180, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM865", "UTF-8", 35704, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM865", 36016, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM866", "UTF-8", 36540, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM866", 36996, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("IBM869", "UTF-8", 37488, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "IBM869", 38004, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACCROATIAN", "UTF-8", 38528, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACCROATIAN", 39360, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACCYRILLIC", "UTF-8", 39884, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACCYRILLIC", 40588, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACGREEK", "UTF-8", 41112, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACGREEK", 41812, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACICELAND", "UTF-8", 42336, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACICELAND", 43052, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACROMAN", "UTF-8", 43576, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACROMAN", 44060, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACROMANIA", "UTF-8", 44584, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACROMANIA", 44960, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACTURKISH", "UTF-8", 45480, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACTURKISH", 45836, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("MACUKRAINE", "UTF-8", 46360, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "MACUKRAINE", 46584, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("KOI8-U", "UTF-8", 47108, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "KOI8-U", 47892, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("KOI8-R", "UTF-8", 48416, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "KOI8-R", 48948, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("TIS-620", "UTF-8", 49312, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "TIS-620", 49356, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("CP850", "UTF-8", 49880, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "CP850", 50428, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("CP852", "UTF-8", 29040, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "CP852", 29656, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("CP855", "UTF-8", 30180, "SingleByte", 1, 1, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "CP855", 30732, "SingleByte", 1, 4, 1, AsciiCompatibility.CONVERTER, 0),
+        new GenericTranscoderEntry("UTF-8", "UTF8-MAC", 52420, "Utf8Mac", 1, 4, 9, AsciiCompatibility.CONVERTER, 0)
     };
+
+    public static Transcoder getInstance(String name) {
+        switch (name) {
+            case "Iso2022jp_kddi_decoder": return Iso2022jp_kddi_decoder_Transcoder.INSTANCE;
+            case "Iso2022jp_kddi_encoder": return Iso2022jp_kddi_encoder_Transcoder.INSTANCE;
+            case "Escape_xml_attr_quote": return Escape_xml_attr_quote_Transcoder.INSTANCE;
+            case "From_GB18030": return From_GB18030_Transcoder.INSTANCE;
+            case "To_GB18030": return To_GB18030_Transcoder.INSTANCE;
+            case "Iso2022jp_decoder": return Iso2022jp_decoder_Transcoder.INSTANCE;
+            case "Iso2022jp_encoder": return Iso2022jp_encoder_Transcoder.INSTANCE;
+            case "Stateless_iso2022jp_to_eucjp": return Stateless_iso2022jp_to_eucjp_Transcoder.INSTANCE;
+            case "Eucjp_to_stateless_iso2022jp": return Eucjp_to_stateless_iso2022jp_Transcoder.INSTANCE;
+            case "Cp50220_decoder": return Cp50220_decoder_Transcoder.INSTANCE;
+            case "Cp50221_decoder": return Cp50221_decoder_Transcoder.INSTANCE;
+            case "Cp50221_encoder": return Cp50221_encoder_Transcoder.INSTANCE;
+            case "Cp50220_encoder": return Cp50220_encoder_Transcoder.INSTANCE;
+            case "Eucjp2sjis": return Eucjp2sjis_Transcoder.INSTANCE;
+            case "Sjis2eucjp": return Sjis2eucjp_Transcoder.INSTANCE;
+            case "Universal_newline": return Universal_newline_Transcoder.INSTANCE;
+            case "From_UTF8_MAC": return From_UTF8_MAC_Transcoder.INSTANCE;
+            case "From_UTF_16BE": return From_UTF_16BE_Transcoder.INSTANCE;
+            case "To_UTF_16BE": return To_UTF_16BE_Transcoder.INSTANCE;
+            case "From_UTF_16LE": return From_UTF_16LE_Transcoder.INSTANCE;
+            case "To_UTF_16LE": return To_UTF_16LE_Transcoder.INSTANCE;
+            case "From_UTF_32BE": return From_UTF_32BE_Transcoder.INSTANCE;
+            case "To_UTF_32BE": return To_UTF_32BE_Transcoder.INSTANCE;
+            case "From_UTF_32LE": return From_UTF_32LE_Transcoder.INSTANCE;
+            case "To_UTF_32LE": return To_UTF_32LE_Transcoder.INSTANCE;
+            case "From_UTF_16": return From_UTF_16_Transcoder.INSTANCE;
+            case "From_UTF_32": return From_UTF_32_Transcoder.INSTANCE;
+            case "To_UTF_16": return To_UTF_16_Transcoder.INSTANCE;
+            case "To_UTF_32": return To_UTF_32_Transcoder.INSTANCE;
+            default: return Transcoder.load(name);
+        }
+    }
 }
